Description Usage Format Source
Personal characteristics are recorded for students taking S Statistics in 1993-4. Fitness level was recorded on an informal scale, the details of which now elude me. The important information is that higher numbers are supposed to represent greater levels of fitness.
1 |
A data frame with 55 rows and 8 columns.
| [,1] | Gender | numeric | gender coded as 1 or 0 |
| [,2] | Height | numeric | height in inches" |
| [,3:4] | Stone, Lb | numeric | weight in stone and pounds |
| [,5] | Shoe | numeric | shoe size (British) |
| [,6:7] | Years, Months | numeric | age in years and months |
| [,8] | Fitness | numeric | self-assessed fitness level |
Peter Craig <P.S.Craig@durham.ac.uk>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.